@@ -10,7 +10,7 @@
 Utilities to read the RESID resource file and build loadable documents and identifier
     correspondences.
 """
-__docformat__ = "restructuredtext en"
+__docformat__ = "google.en"
 __author__ = "John Westbrook"
 __email__ = "jwest@rcsb.rutgers.edu"
 __license__ = "Apache 2.0"
@@ -32,7 +32,8 @@ class ResidProvider(object):
 
     def __init__(self, **kwargs):
         #
-        urlTarget = kwargs.get("residUrlTarget", "ftp://ftp.pir.georgetown.edu/pir_databases/other_databases/resid/RESIDUES.XML")
+        # urlTarget = kwargs.get("residUrlTarget", "ftp://ftp.pir.georgetown.edu/pir_databases/other_databases/resid/RESIDUES.XML")
+        urlTarget = kwargs.get("residUrlTarget", "https://ftp.proteininformationresource.org/pir_databases/other_databases/resid/RESIDUES.XML")
         urlTargetFallback = "https://github.com/rcsb/py-rcsb_exdb_assets/raw/master/fall_back/RESIDUES.XML"
         #
         useCache = kwargs.get("useCache", True)
